﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using RimWorld;
using Verse;
using HarmonyLib;
using UnityEngine;

namespace BeautyAndUgly
{
    public static class BeautyAndUglyDatabase
    {
        public struct BeautyData
        {
            string headPath;
            int beautyLevel;

            BeautyData(string path, int level)
            {
                this.headPath = path;
                this.beautyLevel = level;
            }
        }

        private static Dictionary<BeautyData, Graphic> BeautyHeadDictionary = new Dictionary<BeautyData, Graphic>();

    }



    [StaticConstructorOnStartup]
    public class BeautyAndUglyMain
    {
        static BeautyAndUglyMain()
        {
            //Log.Message("TestMod");
            var harmony = new Harmony("BeautyAndUgly");
            harmony.PatchAll();

        }
    }
    [HarmonyPatch(typeof(PawnGraphicSet))]
    [HarmonyPatch("ResolveAllGraphics")]
    class HeadPatch
    {
        //static bool doLog = true;
        //1.1 and 1.2
        [Obsolete]
        static void OldPostfix(ref PawnGraphicSet __instance)
        {
            if (__instance.pawn.RaceProps.Humanlike)
            {
                var beautyTrait = __instance.pawn.story.traits.GetTrait(TraitDef.Named("Beauty"));
                float pawnBeauty = __instance.pawn.GetStatValue(StatDefOf.PawnBeauty);


                bool flag = true;
                int beautyLevel = 0;

                if (BeautyAndUglySetting.UseBeautyTrait)
                {
                    if (beautyTrait != null)
                    {
                        flag = false;
                        beautyLevel = beautyTrait.Degree;
                    }
                }
                else
                    beautyLevel = (int)Math.Round(pawnBeauty);



                if (flag)
                {
                    var newPath = __instance.pawn.story.HeadGraphicPath + "_Beauty" + beautyLevel;
                    //__instance.headGraphic.path = newPath;
                    if (ContentFinder<Texture2D>.Get(newPath + "_south", false) != null)
                    {
                        __instance.headGraphic = GraphicDatabase.Get<Graphic_Multi>(newPath, ShaderDatabase.CutoutSkin, UnityEngine.Vector2.one, __instance.pawn.story.SkinColor);
                        /////__instance.desiccatedHeadGraphic = GraphicDatabase.Get<Graphic_Multi>(newPath, ShaderDatabase.CutoutSkin, UnityEngine.Vector2.one, PawnGraphicSet.RottingColor); /////PawnGraphicSet.RottingColor has been removed from 1.3
                        return;
                    }
                    else
                    {
                        if (BeautyAndUglySetting.DebugLog == true) 
                        {
                            Log.Warning("Can not find Ugly or Beauty Head Texture for " + __instance.pawn.Name.ToString()+ ";Missing Head Path: " + newPath);
                        }
                    }
                }
            }
            return;

        }
        //1.3
        static void Postfix(ref PawnGraphicSet __instance)
        {
            if (__instance.pawn.RaceProps.Humanlike)
            {
                var beautyTrait = __instance.pawn.story.traits.GetTrait(TraitDef.Named("Beauty"));
                float pawnBeauty = __instance.pawn.GetStatValue(StatDefOf.PawnBeauty);


                bool flag = true;
                int beautyLevel = 0;

                if (BeautyAndUglySetting.UseBeautyTrait)
                {
                    if (beautyTrait != null)
                    {
                        flag = true;
                        beautyLevel = beautyTrait.Degree;
                    }
                    else
                    {
                        flag = false;
                    }
                }
                else
                    beautyLevel = (int)Math.Round(pawnBeauty);


                if (flag)
                {
                    var newPath = __instance.pawn.story.HeadGraphicPath + "_Beauty" + beautyLevel;
                    //__instance.headGraphic.path = newPath;
                    if (ContentFinder<Texture2D>.Get(newPath + "_south", false) != null)
                    {
                        __instance.headGraphic = GraphicDatabase.Get<Graphic_Multi>(newPath, __instance.headGraphic.Shader, __instance.headGraphic.drawSize, __instance.headGraphic.color, __instance.headGraphic.ColorTwo);
                        __instance.desiccatedHeadGraphic = GraphicDatabase.Get<Graphic_Multi>(newPath, __instance.desiccatedHeadGraphic.Shader, __instance.desiccatedHeadGraphic.drawSize, __instance.desiccatedHeadGraphic.color, __instance.desiccatedHeadGraphic.ColorTwo); /////PawnGraphicSet.RottingColor has been removed from 1.3
                        return;
                    }
                    else
                    {
                        if (BeautyAndUglySetting.DebugLog == true)
                        {
                            Log.Warning("Can not find Ugly or Beauty Head Texture for " + __instance.pawn.Name.ToString() + ";Missing Head Path: " + newPath);
                        }
                    }
                }
            }
            return;

        }
    }

}

